function [FE,meanlt,jitter,lt]=APstats(modelname,I0,nrep)

% APstats calculates spike statistics for multiple repetitions of a
% stimulus applied to a stochastic Hodgkin-Huxley model from:
%
%    Bruce, I. C. (2007). "Implementation issues in approximate methods for
%    stochastic HodgkinHuxley models," Annals of Biomedical Engineering
%    35(2):315318.
%
% [FE,meanlt,jitter,lt]=APstats(modelname,I0,nrep)
%
% FE is the firing efficiency, i.e., the fraction of trials in which a
%    spike is generated.
% meanlt is the mean latency of spikes in units of millisecond.
% jitter is the standard deviation of spike latencies in units of millisecond.
% lt is the spike latencies in units of millisecond.
%
% modelname is the model type, which may be one of the following:-
%    - 'hhfloor': Deterministic Hodgkin-Huxley model with N_Na rounded down.
%    - 'hhnint':  Deterministic Hodgkin-Huxley model with N_Na rounded to
%                 nearest integer.
%    - 'fxfloor': Fox algorithm with N_Na rounded down.
%    - 'fxnint':  Fox algorithm with N_Na rounded to nearest integer.
%    - 'cw':      Chow & White algorithm.
% I0 is the current amplitude in units of picoampere.  A single value
%    (e.g., I0 = 22) produces a single pulse of duration 100 microsecond
%    and amplitude I0 pA.
%    A pair of values (e.g., I0 = [22 35]) produces a conditioning prepulse
%    of duration 500 microsecond & amplitude I0(1) pA and a pulse of
%    duration 100 microsecond & amplitude I0(2) pA.
% nrep is the number of repetitions (trials)
%
% Ian C. Bruce (ibruce@ieee.org)  2007

% Create vectors for spike results
sp = zeros(1,nrep); % Spike occurences
lt_n = zeros(1,nrep); % Latencies in terms of time bin number
lt = zeros(1,nrep); % Latencies in terms of time in milliseconds

%Setup the waitbar.
wb1 = waitbar(0,['Running ' modelname '...']);
set(wb1,'name','APstats - 0%');

% Repeat simulation nrep times

for k = 1:nrep

    [V,N_Na,Istim,t] = stochasticHH(modelname,I0); % Run the chosen model
    
    sp(k) = max(V) > 100; % A spike has occurred if the peak relative
                          % membrane potential exceeds 100 mV
                          
    if sp(k)              % If a spike has occurred, determine latency
        lt_n(k) = find(V == max(V));
        lt(k) = t(lt_n(k));
    else              % Latency not defined, if no spike has occurred
        lt_n(k) = NaN;
        lt(k) = NaN;
    end
    
    %UPDATE WAIT-BAR every 1%
    if (mod(k,(round(nrep/100))) == 0)
        waitbar(k/nrep,wb1)
        set(wb1,'name',['APstats - ' sprintf('%2.1f',k/nrep*100) '%'])
    end
    
end

%Close Waitbar
close(wb1)

FE = sum(sp)/nrep; % Calculate firing efficiency
if FE>0 % If any spikes have been generated, calculate mean latency and jitter
    meanlt = mean(lt(find(~isnan(lt))));
    jitter = std(lt(find(~isnan(lt))));
else % Mean latency and jitter not defined, if no spikes have occurred
    meanlt = NaN;
    jitter = NaN;
end
