% bruceABME_figs1and2  Run simulations and plot results corresponding to
%                      Figures 1 and 2 from:
%
%                      Bruce, I. C. (2007). "Implementation issues in
%                      approximate methods for stochastic HodgkinHuxley
%                      models," Annals of Biomedical Engineering
%                      35(2):315318.
%
% Ian C. Bruce (ibruce@ieee.org)  2007


% Create vector of stimulus current amplitudes
Is = (4.9:0.1:6.5)/0.265;
lps = length(Is);

% Create vectors for simulation results
FE_cw = zeros(1,lps);
meanlt_cw = zeros(1,lps);
jitter_cw = zeros(1,lps);

FE_fxfloor = zeros(1,lps);
meanlt_fxfloor = zeros(1,lps);
jitter_fxfloor = zeros(1,lps);

FE_fxnint = zeros(1,lps);
meanlt_fxnint = zeros(1,lps);
jitter_fxnint = zeros(1,lps);

% Run loop over stimulus current amplitudes
for lp = 1:lps

	disp(['Run ' num2str(lp) '/' num2str(lps)])
    drawnow

    disp('Chow & White model running...')
    [FE_cw(lp),meanlt_cw(lp),jitter_cw(lp)]=APstats('cw',Is(lp),1e3);

    disp('Fox (floor) model running...')
    [FE_fxfloor(lp),meanlt_fxfloor(lp),jitter_fxfloor(lp)]=APstats('fxfloor',Is(lp),1e3);

    disp('Fox (nint) model running...')
    [FE_fxnint(lp),meanlt_fxnint(lp),jitter_fxnint(lp)]=APstats('fxnint',Is(lp),1e3);
    
end

figure

subplot(3,1,1)
feplot1=plot(Is,FE_cw,'k*');
hold on
feplot2=plot(Is,FE_fxfloor,'ko');
feplot3=plot(Is,FE_fxnint,'ks');
ylabel('FE')
legend([feplot1, feplot2, feplot3],'Chow & White','Fox - \lfloorN_{Na}\rfloor','Fox - nint(N_{Na})','Location','SouthEast')

% Find integrated-Gaussian fits to FE versus I results
X_cw = fminsearch(@(x) intgausserr(x,Is,FE_cw),[22 0.03*22]);
X_fxfloor = fminsearch(@(x) intgausserr(x,Is,FE_fxfloor),[22 0.03*22]);
X_fxnint = fminsearch(@(x) intgausserr(x,Is,FE_fxnint),[22 0.03*22]);

% Display threshold and RS values for integrated-Gaussian fits
disp(' ')
disp(['Chow & White: Ithr = ' num2str(X_cw(1),'%4.2f') ' pA; RS = ' num2str(X_cw(2)/X_cw(1),'%5.4f')])
disp(['Fox (floor): Ithr = ' num2str(X_fxfloor(1),'%4.2f') ' pA; RS = ' num2str(X_fxfloor(2)/X_fxfloor(1),'%5.4f')])
disp(['Fox (nint): Ithr = ' num2str(X_fxnint(1),'%4.2f') ' pA; RS = ' num2str(X_fxnint(2)/X_fxnint(1),'%5.4f')])

% Plot integrated-Gaussian fits to FE versus I results
I = linspace(Is(1),Is(end),100);
intgauss_cw = 1/2*(erf((I-X_cw(1))/sqrt(2)/X_cw(2))+1);
intgauss_fxfloor = 1/2*(erf((I-X_fxfloor(1))/sqrt(2)/X_fxfloor(2))+1);
intgauss_fxnint = 1/2*(erf((I-X_fxnint(1))/sqrt(2)/X_fxnint(2))+1);
plot(I,intgauss_cw,'k-')
plot(I,intgauss_fxfloor,'k-')
plot(I,intgauss_fxnint,'k-')

subplot(3,1,2)
ltplot1=plot(Is,meanlt_cw,'k*-');
hold on
ltplot2=plot(Is,meanlt_fxfloor,'ko-');
ltplot3=plot(Is,meanlt_fxnint,'ks-');
ylabel('Mean latency [ms]')
ylim([0.1 0.5])

subplot(3,1,3)
jtplot1=plot(Is,jitter_cw,'k*-');
hold on
jtplot2=plot(Is,jitter_fxfloor,'ko-');
jtplot3=plot(Is,jitter_fxnint,'ks-');
ylabel('Jitter [ms]')
xlabel('Simulus current [pA]')

figure

subplot(2,1,1)
ltplot1=plot(FE_cw,meanlt_cw,'k*-');
hold on
ltplot2=plot(FE_fxfloor,meanlt_fxfloor,'ko-');
ltplot3=plot(FE_fxnint,meanlt_fxnint,'ks-');
ylabel('Mean latency [ms]')
legend([ltplot1, ltplot2, ltplot3],'Chow & White','Fox - \lfloorN_{Na}\rfloor','Fox - nint(N_{Na})','Location','NorthEast')
ylim([0.1 0.5])

subplot(2,1,2)
jtplot1=plot(FE_cw,jitter_cw,'k*-');
hold on
jtplot2=plot(FE_fxfloor,jitter_fxfloor,'ko-');
jtplot3=plot(FE_fxnint,jitter_fxnint,'ks-');
ylabel('Jitter [ms]')
xlabel('FE')
